#region Copyright Syncfusion Inc. 2001 - 2005
//
//  Copyright Syncfusion Inc. 2001 - 2005. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Re-distribution in any form is strictly
//  prohibited. Any infringement will be prosecuted under applicable laws. 
//
#endregion

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Runtime.Serialization;
using System.Windows.Forms;
using System.IO;

using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;


namespace GridSample
{
	public class LiveCalendarCellModel : GridGenericControlCellModel
	{
		public LiveCalendarCellModel(GridModel grid)
			: base(grid)
		{
		}
	
		protected LiveCalendarCellModel(SerializationInfo info, StreamingContext context)
			: base(info, context)
		{
		}

		public override GridCellRendererBase CreateRenderer(GridControlBase control)
		{
			return new LiveCalendarCellRenderer(control, this);
		}

		static Size calendarControlSize = Size.Empty;

		public static Size CalendarControlSize 
		{
			get
			{
				if (calendarControlSize.IsEmpty)
				{
					// Determine default size of MonthCalendar when shown in a form
					TopLevelWindow f = new TopLevelWindow();
					f.Location = new Point(10000, 10000);
					f.Size = new Size(500, 500);
					f.ShowWindowTopMost();
					MonthCalendar drawCalendar = new MonthCalendar();
					f.Controls.Add(drawCalendar);
					f.Visible = true;
					calendarControlSize = drawCalendar.Size;
					f.Dispose();
				}
				return calendarControlSize;
			}
		}



		protected override Size OnQueryPrefferedClientSize(Graphics g, int rowIndex, int colIndex, GridStyleInfo style, GridQueryBounds queryBounds)
		{
			Size size = CalendarControlSize;
			size.Width += 8;
			size.Height += 8;
			return size;
		}

		public static void InitializeCalendar(MonthCalendar c, GridStyleInfo style)
		{
			InitializeCalendar(c, style.CellValue);
		}

		public static void InitializeCalendar(MonthCalendar c, object controlValue)
		{
			if (controlValue is DateTime)
				c.SetDate((DateTime) controlValue);
			else if (controlValue is string && ((string) controlValue).Length > 0)
				c.SetDate(DateTime.Parse((string) controlValue));
			else
				c.SetDate(DateTime.Today);
		}

	}
	
	public class LiveCalendarCellRenderer: GridGenericControlCellRenderer
	{
		MonthCalendar editCalendar = new MonthCalendar();
		LiveCalendarCellModel cm;
		
		public LiveCalendarCellRenderer(GridControlBase grid, GridCellModelBase cellModel)
			: base(grid, cellModel)
		{
			cm = (LiveCalendarCellModel) cellModel;
			SupportsFocusControl = true;
			FixControlParent(editCalendar);
			SetControl(editCalendar);
			editCalendar.DateChanged += new DateRangeEventHandler(calendar_DateChanged);
		}

		protected override void Dispose(bool disposing)
		{
			if (disposing)
			{
				editCalendar.DateChanged -= new DateRangeEventHandler(calendar_DateChanged);
				editCalendar.Dispose();
				editCalendar = null;
				cm = null;
			}

			base.Dispose (disposing);
		}

		protected /*internal*/ override bool OnSaveChanges()
		{
			this.Grid.Model[RowIndex, ColIndex].CellValue = editCalendar.SelectionStart;
			return true;
		}

		
		protected override void OnActivated()
		{
			// Works around some interaction problem with PropertyGrid specific to this sample: force redrawing of
			// calendar after property grid was refreshed.
			Timer t = new Timer();
			t.Tick += new EventHandler(t_Tick);
			t.Interval = 200;
			t.Start();

			base.OnActivated ();
		}

		private void t_Tick(object sender, EventArgs e)
		{
			Timer t = (Timer) sender;
			t.Tick += new EventHandler(t_Tick);
			t.Dispose();

			//this.Grid.InvalidateRange(GridRangeInfo.Cell(RowIndex, ColIndex));
			editCalendar.Refresh();
		}
		
		protected override void OnDraw(Graphics g, Rectangle clientRectangle, int rowIndex, int colIndex, GridStyleInfo style)
		{
			Syncfusion.Diagnostics.TraceUtil.TraceCurrentMethodInfo(clientRectangle);
			if (!Grid.PrintingMode)
			{
				Control control = editCalendar;
				style.Control = editCalendar;
				control.Bounds = clientRectangle;
				control.Invalidate();
				if (!control.ContainsFocus)
					control.Focus();
			}
			else
			{
				style.Control = editCalendar;
				base.OnDraw (g, clientRectangle, rowIndex, colIndex, style);
			}
		}

		protected override void InitializeControlText(object controlValue)
		{
			LiveCalendarCellModel.InitializeCalendar(this.editCalendar, controlValue);
		}

		protected override Rectangle OnLayout(int rowIndex, int colIndex, GridStyleInfo style, Rectangle innerBounds, Rectangle[] buttonsBounds)
		{
			Rectangle r = base.OnLayout (rowIndex, colIndex, style, innerBounds, buttonsBounds);

			r.Inflate(-1, -1);
			
			// center windows forms calendar inside cell.
			r = GridUtil.CenterInRect(r, LiveCalendarCellModel.CalendarControlSize);
			r.Size = GridUtil.Max(r.Size, LiveCalendarCellModel.CalendarControlSize);
			return r;
		}

		private void calendar_DateChanged(object sender, DateRangeEventArgs e)
		{
			// Raise CurrentCellChanging event and set CurrentCell.Modified = true
			if (base.NotifyCurrentCellChanging())
			{
				ControlValue = editCalendar.SelectionStart;
				base.NotifyCurrentCellChanged();
			}
		}
	}

}
