#region Copyright Syncfusion Inc. 2001 - 2005
//
//  Copyright Syncfusion Inc. 2001 - 2005. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Re-distribution in any form is strictly
//  prohibited. Any infringement will be prosecuted under applicable laws. 
//
#endregion

using System;
using System.Drawing;
using System.Collections;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Text;

using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Diagnostics;

namespace GridSample
{
	/// <summary>
	/// Summary description for MainForm.
	/// </summary>
	public class MainForm
	{
		Syncfusion.Windows.Forms.Grid.GridControl gridControl1;
		Syncfusion.Windows.Forms.SplitterControl splitterControl1;
		DataSet1 dataSet11;
		Form1 form;

		public MainForm(Form1 form)
		{
			this.form = form;
			this.gridControl1 = form.gridControl1;
			this.splitterControl1 = form.splitterControl1;
			this.dataSet11 = form.dataSet11;
			InitializeForm();
		}

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		public static void Main() 
		{
			Form1 form = new Form1();
			MainForm main = new MainForm(form);
			Application.Run(form);
		}

		void InitializeForm()
		{
			form.Text = "Calendar Cells";

			gridControl1.Properties.RowHeaders = false;
			gridControl1.Properties.ColHeaders = false;

			gridControl1.BeginUpdate();
			gridControl1.TableStyle.FloatCell = true;
			gridControl1.AllowDragSelectedCols = false;
			gridControl1.AllowDragSelectedRows = false;
			gridControl1.AllowSelection = GridSelectionFlags.Any;
			gridControl1.ControllerOptions &= ~(GridControllerOptions.OleDataSource|GridControllerOptions.DragSelectRowOrColumn|GridControllerOptions.ExcelLikeSelection|GridControllerOptions.OleDataSource);
			gridControl1.FloatCellsMode = GridFloatCellsMode.OnDemandCalculation;
			gridControl1.CellModels.Add("Calendar", new LiveCalendarCellModel(gridControl1.Model));

			GridStyleInfo style;

			gridControl1.ColWidths[1] = 20;

			int row = 2; 
			style = gridControl1[row, 2];
			style.CellType = "Calendar";

			gridControl1.RowHeights.ResizeToFit(GridRangeInfo.Rows(2, 6));
			gridControl1.ColWidths.ResizeToFit(GridRangeInfo.Cols(2,3));
			
			gridControl1.EndUpdate(true);

			gridControl1.ResizingColumns += new GridResizingColumnsEventHandler(gridControl1_ResizingColumns);
			gridControl1.ResizingRows += new GridResizingRowsEventHandler(gridControl1_ResizingRows);

			gridControl1.ForceCurrentCellMoveTo = true;
			gridControl1.CurrentCell.MoveTo(2, 2);
			form.ShowPropertyGridItem("Cell Value", "Text");
		}

		private void gridControl1_ResizingColumns(object sender, GridResizingColumnsEventArgs e)
		{
			if (e.Reason == GridResizeCellsReason.CancelMode
				|| e.Reason == GridResizeCellsReason.HitTest
				|| e.Reason == GridResizeCellsReason.ResetHide
				|| e.Reason == GridResizeCellsReason.MouseDown)
				return;

			if (e.Columns.IntersectsWith(GridRangeInfo.Cols(2,3)))
			{
				if (e.Width < LiveCalendarCellModel.CalendarControlSize.Width+2)
					e.Cancel = true;
			}
			e.SizeIndicatorBorder = new GridBorder(GridBorderStyle.Dashed, Color.Blue, GridBorderWeight.Thick);

		}

		private void gridControl1_ResizingRows(object sender, GridResizingRowsEventArgs e)
		{
			if (e.Reason == GridResizeCellsReason.CancelMode
				|| e.Reason == GridResizeCellsReason.HitTest
				|| e.Reason == GridResizeCellsReason.ResetHide
				|| e.Reason == GridResizeCellsReason.MouseDown)
				return;

			if (e.Rows.IntersectsWith(GridRangeInfo.Rows(2,6)))
			{
				if (e.Height< LiveCalendarCellModel.CalendarControlSize.Height+4)
					e.Cancel = true;
			}
		}
	}
}